/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
import { ElementRef, EventEmitter } from '@angular/core';
import { AnimationGroupMetadata } from '@angular/animations';
import { MatDrawerMode, MatSidenav } from '@angular/material/sidenav';
import { HeaderComponent } from '../../components/header/header.component';
import { SidenavItem } from '../../interfaces/sidenav.interface';
import { SidenavUtilService } from '../../services/sidenav-util.service';
import * as i0 from "@angular/core";
/**
 * Defines the default layout for the app, which consists of the header, footer,
 * and main content based on the current route. The layout should have a sticky
 * footer, meaning if the main content is not tall enough to fill the existing
 * space, then the footer will stick to the bottom of the page.
 *
 * @usageNotes
 * #### Basic Usage Example
 * ```html
 * <ngx-mat-default-layout [logo]="logo" [sidenavItems]="sidenavItems">
 *  </ngx-mat-default-layout>
 * ```
 * ```typescript
 * import {Component} from '@angular/core';
 * import {SidenavItem} from '@ngx-material-dashboard/widgets';
 *
 * @Component({
 *     selector: 'basic-usage-example',
 *     templateUrl: './basic-usage-example.html'
 * })
 * export class BasicUsageExample {
 *     logo = 'My Tasks';
 *     sidenavItems: SidenavItem[] = [
 *         { queryParams: { isComplete: false }, route: ['tasks'], text: 'Pending', selector: 'pending' },
 *         { queryParams: { isComplete: false, filter: 'overdue' }, route: ['tasks'], text: 'Over Due', selector: 'over-due' },
 *         { queryParams: { isComplete: true }, route: ['tasks'], text: 'Complete', selector: 'complete' }
 *     ];
 * }
 * ```
 *
 * @
 */
export declare class DefaultLayoutComponent {
    private sidenavUtilService;
    /** Text to display next to copyright date. */
    company: string;
    /** The main "logo" text for the app to display in the header. */
    logo: string;
    /** The mode for the drawer (i.e. 'over', 'push', 'side', or 'rail'). */
    mode: MatDrawerMode | 'rail';
    /** List of items to render in the sidenav. */
    sidenavItems: SidenavItem[];
    /** Boolean indicating whether the screen size is small (defaults to false). */
    isSmallScreen: boolean;
    routeActivate: EventEmitter<any>;
    /** Event emitted when user clicks search button in filter. */
    clickSearch: EventEmitter<boolean>;
    /**
     * @deprecated Not used, will be removed in a later release.
     */
    header: HeaderComponent;
    /**
     * @deprecated No longer used. Will be removed in a later release.
     */
    sidenavElement: ElementRef;
    /** The sidenav defined in the template. */
    sidenav: MatSidenav;
    /**
     * @deprecated No longer used. Will be removed in a later release.
     */
    defaultDuration: string;
    /**
     * Boolean indicating if sidenav is collapsed (only used if mode = 'rail').
     * Separate from opened, since MatSidenav will always remain open if mode
     * is set to rail. It's just the contents that "collapse".
     */
    collapsed: boolean;
    /** Boolean indicating if MatSidenav is open. */
    opened: boolean;
    /**
     * @deprecated No longer used. Will be removed in a later release.
     */
    sidenavWidth: number;
    /**
     * @deprecated No longer used. Will be removed in a later release.
     */
    width: string;
    /**
     * Returns the MatDrawerMode for the MatSidenav. If the defined mode is set
     * to 'rail', the MatDrawerMode is set to 'side'. Otherwise the mode should
     * already be a MatDrawerMode, so just return that then.
     */
    get matSidenavMode(): MatDrawerMode;
    constructor(sidenavUtilService: SidenavUtilService);
    onActivate(cmp: any): void;
    /**
     * Handler for when the user clicks the search button in the filter.
     *
     * @param res Boolean value to indicate if search button was clicked.
     */
    onSearchFilterClick(res: boolean): void;
    /**
     * This is taken directly from angular-material-rail-drawer and is a
     * workaround to issue with sidenav not expanding to fit content.
     *
     * @deprecated No longer used since angular-material-rail-drawer removed. Method will be removed in a future release.
     *
     * @param animationDuration Duration in ms to use for animation.
     * @param maxWidth The maximum expanded width for the sidenav.
     * @returns
     */
    sidebarAnimationOpenGroup(animationDuration?: string, maxWidth?: string): AnimationGroupMetadata;
    /**
     * Toggles the sidenav.
     */
    toggleSidenav(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DefaultLayoutComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DefaultLayoutComponent, "ngx-mat-default-layout", never, { "company": "company"; "logo": "logo"; "mode": "mode"; "sidenavItems": "sidenavItems"; "isSmallScreen": "isSmallScreen"; }, { "routeActivate": "routeActivate"; "clickSearch": "clickSearch"; }, never, ["[filter]"]>;
}
